==> zio-aws-securityhub_2.13-5.17.115.1-sources.jar: zio/aws/securityhub/model/AwsEc2SubnetDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{Integer, NonEmptyString}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsEc2SubnetDetails(
    assignIpv6AddressOnCreation: Option[Boolean] = None,
    availabilityZone: Option[NonEmptyString] = None,
    availabilityZoneId: Option[NonEmptyString] = None,
    availableIpAddressCount: Option[Integer] = None,
    cidrBlock: Option[NonEmptyString] = None,
    defaultForAz: Option[Boolean] = None,
    mapPublicIpOnLaunch: Option[Boolean] = None,
    ownerId: Option[NonEmptyString] = None,
    state: Option[NonEmptyString] = None,
    subnetArn: Option[NonEmptyString] = None,
    subnetId: Option[NonEmptyString] = None,
    vpcId: Option[NonEmptyString] = None,
    ipv6CidrBlockAssociationSet: Option[
      Iterable[zio.aws.securityhub.model.Ipv6CidrBlockAssociation]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails = {
    import AwsEc2SubnetDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails
      .builder()
      .optionallyWith(
        assignIpv6AddressOnCreation.map(value => value: java.lang.Boolean)
      )(_.assignIpv6AddressOnCreation)
      .optionallyWith(
        availabilityZone.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.availabilityZone)
      .optionallyWith(
        availabilityZoneId.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.availabilityZoneId)
      .optionallyWith(
        availableIpAddressCount.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.availableIpAddressCount)
      .optionallyWith(
        cidrBlock.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.cidrBlock)
      .optionallyWith(defaultForAz.map(value => value: java.lang.Boolean))(
        _.defaultForAz
      )
      .optionallyWith(
        mapPublicIpOnLaunch.map(value => value: java.lang.Boolean)
      )(_.mapPublicIpOnLaunch)
      .optionallyWith(
        ownerId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.ownerId)
      .optionallyWith(
        state.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.state)
      .optionallyWith(
        subnetArn.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.subnetArn)
      .optionallyWith(
        subnetId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(
        vpcId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.vpcId)
      .optionallyWith(
        ipv6CidrBlockAssociationSet.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.ipv6CidrBlockAssociationSet)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.AwsEc2SubnetDetails.ReadOnly =
    zio.aws.securityhub.model.AwsEc2SubnetDetails.wrap(buildAwsValue())
}
object AwsEc2SubnetDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.AwsEc2SubnetDetails =
      zio.aws.securityhub.model.AwsEc2SubnetDetails(
        assignIpv6AddressOnCreation.map(value => value),
        availabilityZone.map(value => value),
        availabilityZoneId.map(value => value),
        availableIpAddressCount.map(value => value),
        cidrBlock.map(value => value),
        defaultForAz.map(value => value),
        mapPublicIpOnLaunch.map(value => value),
        ownerId.map(value => value),
        state.map(value => value),
        subnetArn.map(value => value),
        subnetId.map(value => value),
        vpcId.map(value => value),
        ipv6CidrBlockAssociationSet.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def assignIpv6AddressOnCreation: Option[Boolean]
    def availabilityZone: Option[NonEmptyString]
    def availabilityZoneId: Option[NonEmptyString]
    def availableIpAddressCount: Option[Integer]
    def cidrBlock: Option[NonEmptyString]
    def defaultForAz: Option[Boolean]
    def mapPublicIpOnLaunch: Option[Boolean]
    def ownerId: Option[NonEmptyString]
    def state: Option[NonEmptyString]
    def subnetArn: Option[NonEmptyString]
    def subnetId: Option[NonEmptyString]
    def vpcId: Option[NonEmptyString]
    def ipv6CidrBlockAssociationSet: Option[
      List[zio.aws.securityhub.model.Ipv6CidrBlockAssociation.ReadOnly]
    ]
    def getAssignIpv6AddressOnCreation: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "assignIpv6AddressOnCreation",
        assignIpv6AddressOnCreation
      )
    def getAvailabilityZone: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getAvailabilityZoneId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("availabilityZoneId", availabilityZoneId)
    def getAvailableIpAddressCount: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("availableIpAddressCount", availableIpAddressCount)
    def getCidrBlock: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("cidrBlock", cidrBlock)
    def getDefaultForAz: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("defaultForAz", defaultForAz)
    def getMapPublicIpOnLaunch: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("mapPublicIpOnLaunch", mapPublicIpOnLaunch)
    def getOwnerId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("ownerId", ownerId)
    def getState: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("state", state)
    def getSubnetArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("subnetArn", subnetArn)
    def getSubnetId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getVpcId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("vpcId", vpcId)
    def getIpv6CidrBlockAssociationSet: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.Ipv6CidrBlockAssociation.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "ipv6CidrBlockAssociationSet",
      ipv6CidrBlockAssociationSet
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails
  ) extends zio.aws.securityhub.model.AwsEc2SubnetDetails.ReadOnly {
    override val assignIpv6AddressOnCreation: Option[Boolean] = scala
      .Option(impl.assignIpv6AddressOnCreation())
      .map(value => value: Boolean)
    override val availabilityZone: Option[NonEmptyString] = scala
      .Option(impl.availabilityZone())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val availabilityZoneId: Option[NonEmptyString] = scala
      .Option(impl.availabilityZoneId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val availableIpAddressCount: Option[Integer] = scala
      .Option(impl.availableIpAddressCount())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
    override val cidrBlock: Option[NonEmptyString] = scala
      .Option(impl.cidrBlock())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val defaultForAz: Option[Boolean] =
      scala.Option(impl.defaultForAz()).map(value => value: Boolean)
    override val mapPublicIpOnLaunch: Option[Boolean] =
      scala.Option(impl.mapPublicIpOnLaunch()).map(value => value: Boolean)
    override val ownerId: Option[NonEmptyString] = scala
      .Option(impl.ownerId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val state: Option[NonEmptyString] = scala
      .Option(impl.state())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val subnetArn: Option[NonEmptyString] = scala
      .Option(impl.subnetArn())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val subnetId: Option[NonEmptyString] = scala
      .Option(impl.subnetId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val vpcId: Option[NonEmptyString] = scala
      .Option(impl.vpcId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val ipv6CidrBlockAssociationSet: Option[
      List[zio.aws.securityhub.model.Ipv6CidrBlockAssociation.ReadOnly]
    ] = scala
      .Option(impl.ipv6CidrBlockAssociationSet())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.Ipv6CidrBlockAssociation.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails
  ): zio.aws.securityhub.model.AwsEc2SubnetDetails.ReadOnly = new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.157.2-sources.jar: zio/aws/securityhub/model/AwsEc2SubnetDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{Integer, NonEmptyString}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsEc2SubnetDetails(
    assignIpv6AddressOnCreation: Option[Boolean] = None,
    availabilityZone: Option[NonEmptyString] = None,
    availabilityZoneId: Option[NonEmptyString] = None,
    availableIpAddressCount: Option[Integer] = None,
    cidrBlock: Option[NonEmptyString] = None,
    defaultForAz: Option[Boolean] = None,
    mapPublicIpOnLaunch: Option[Boolean] = None,
    ownerId: Option[NonEmptyString] = None,
    state: Option[NonEmptyString] = None,
    subnetArn: Option[NonEmptyString] = None,
    subnetId: Option[NonEmptyString] = None,
    vpcId: Option[NonEmptyString] = None,
    ipv6CidrBlockAssociationSet: Option[
      Iterable[zio.aws.securityhub.model.Ipv6CidrBlockAssociation]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails = {
    import AwsEc2SubnetDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails
      .builder()
      .optionallyWith(
        assignIpv6AddressOnCreation.map(value => value: java.lang.Boolean)
      )(_.assignIpv6AddressOnCreation)
      .optionallyWith(
        availabilityZone.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.availabilityZone)
      .optionallyWith(
        availabilityZoneId.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.availabilityZoneId)
      .optionallyWith(
        availableIpAddressCount.map(value => value: java.lang.Integer)
      )(_.availableIpAddressCount)
      .optionallyWith(
        cidrBlock.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.cidrBlock)
      .optionallyWith(defaultForAz.map(value => value: java.lang.Boolean))(
        _.defaultForAz
      )
      .optionallyWith(
        mapPublicIpOnLaunch.map(value => value: java.lang.Boolean)
      )(_.mapPublicIpOnLaunch)
      .optionallyWith(
        ownerId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.ownerId)
      .optionallyWith(
        state.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.state)
      .optionallyWith(
        subnetArn.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.subnetArn)
      .optionallyWith(
        subnetId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(
        vpcId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.vpcId)
      .optionallyWith(
        ipv6CidrBlockAssociationSet.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.ipv6CidrBlockAssociationSet)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.AwsEc2SubnetDetails.ReadOnly =
    zio.aws.securityhub.model.AwsEc2SubnetDetails.wrap(buildAwsValue())
}
object AwsEc2SubnetDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.AwsEc2SubnetDetails =
      zio.aws.securityhub.model.AwsEc2SubnetDetails(
        assignIpv6AddressOnCreation.map(value => value),
        availabilityZone.map(value => value),
        availabilityZoneId.map(value => value),
        availableIpAddressCount.map(value => value),
        cidrBlock.map(value => value),
        defaultForAz.map(value => value),
        mapPublicIpOnLaunch.map(value => value),
        ownerId.map(value => value),
        state.map(value => value),
        subnetArn.map(value => value),
        subnetId.map(value => value),
        vpcId.map(value => value),
        ipv6CidrBlockAssociationSet.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def assignIpv6AddressOnCreation: Option[Boolean]
    def availabilityZone: Option[NonEmptyString]
    def availabilityZoneId: Option[NonEmptyString]
    def availableIpAddressCount: Option[Integer]
    def cidrBlock: Option[NonEmptyString]
    def defaultForAz: Option[Boolean]
    def mapPublicIpOnLaunch: Option[Boolean]
    def ownerId: Option[NonEmptyString]
    def state: Option[NonEmptyString]
    def subnetArn: Option[NonEmptyString]
    def subnetId: Option[NonEmptyString]
    def vpcId: Option[NonEmptyString]
    def ipv6CidrBlockAssociationSet: Option[
      List[zio.aws.securityhub.model.Ipv6CidrBlockAssociation.ReadOnly]
    ]
    def getAssignIpv6AddressOnCreation: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "assignIpv6AddressOnCreation",
        assignIpv6AddressOnCreation
      )
    def getAvailabilityZone: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getAvailabilityZoneId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("availabilityZoneId", availabilityZoneId)
    def getAvailableIpAddressCount: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("availableIpAddressCount", availableIpAddressCount)
    def getCidrBlock: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("cidrBlock", cidrBlock)
    def getDefaultForAz: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("defaultForAz", defaultForAz)
    def getMapPublicIpOnLaunch: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("mapPublicIpOnLaunch", mapPublicIpOnLaunch)
    def getOwnerId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("ownerId", ownerId)
    def getState: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("state", state)
    def getSubnetArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("subnetArn", subnetArn)
    def getSubnetId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getVpcId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("vpcId", vpcId)
    def getIpv6CidrBlockAssociationSet: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.Ipv6CidrBlockAssociation.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "ipv6CidrBlockAssociationSet",
      ipv6CidrBlockAssociationSet
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails
  ) extends zio.aws.securityhub.model.AwsEc2SubnetDetails.ReadOnly {
    override val assignIpv6AddressOnCreation: Option[Boolean] = scala
      .Option(impl.assignIpv6AddressOnCreation())
      .map(value => value: Boolean)
    override val availabilityZone: Option[NonEmptyString] = scala
      .Option(impl.availabilityZone())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val availabilityZoneId: Option[NonEmptyString] = scala
      .Option(impl.availabilityZoneId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val availableIpAddressCount: Option[Integer] =
      scala.Option(impl.availableIpAddressCount()).map(value => value: Integer)
    override val cidrBlock: Option[NonEmptyString] = scala
      .Option(impl.cidrBlock())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val defaultForAz: Option[Boolean] =
      scala.Option(impl.defaultForAz()).map(value => value: Boolean)
    override val mapPublicIpOnLaunch: Option[Boolean] =
      scala.Option(impl.mapPublicIpOnLaunch()).map(value => value: Boolean)
    override val ownerId: Option[NonEmptyString] = scala
      .Option(impl.ownerId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val state: Option[NonEmptyString] = scala
      .Option(impl.state())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val subnetArn: Option[NonEmptyString] = scala
      .Option(impl.subnetArn())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val subnetId: Option[NonEmptyString] = scala
      .Option(impl.subnetId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val vpcId: Option[NonEmptyString] = scala
      .Option(impl.vpcId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val ipv6CidrBlockAssociationSet: Option[
      List[zio.aws.securityhub.model.Ipv6CidrBlockAssociation.ReadOnly]
    ] = scala
      .Option(impl.ipv6CidrBlockAssociationSet())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.Ipv6CidrBlockAssociation.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEc2SubnetDetails
  ): zio.aws.securityhub.model.AwsEc2SubnetDetails.ReadOnly = new Wrapper(impl)
}
